@@ -9,7 +9,7 @@ use Carp;
 use Catmandu::Error;
 use URI;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 with 'Catmandu::Importer';
 
@@ -21,6 +21,8 @@ has from                   => (is => 'ro');
 has until                  => (is => 'ro');
 has resumptionToken        => (is => 'ro');
 
+has strict                 => (is => 'ro');
+
 has identify               => (is => 'ro');
 has listIdentifiers        => (is => 'ro');
 has listRecords            => (is => 'ro');
@@ -224,6 +226,7 @@ sub _args {
         set            => $self->set ,
         from           => $self->from ,
         until          => $self->until ,
+        force          => !$self->strict ,
     );
 
     for( keys %args ) {
@@ -664,6 +667,11 @@ An optional resumptionToken to start harvesting from.
 
 Don't do any HTTP requests but return URLs that data would be queried from.
 
+=item strict
+
+Optional validate all parameters first against the OAI 2 spefications before
+sending it to an OAI server. Default: undef.
+
 =item xslt
 
 Preprocess XML records with XSLT script(s) given as comma separated list or
